# command map
command_map = {
	"start"  : "$HADOOP_HOME/bin/start-all.sh",
	"stop"   : "$HADOOP_HOME/bin/stop-all.sh",
	"cp"     : "$HADOOP_HOME/bin/hadoop fs -cp",
	"rm"     : "$HADOOP_HOME/bin/hadoop fs -rmr",
	"ls"     : "$HADOOP_HOME/bin/hadoop fs -ls",
}


# meta file for project distribution
import os, sys
from setuptools import setup

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now
# 1) we have a top level README.md file and 
# 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
  name = 'pyhadoop',
  packages = ['pyhadoop'], # this must be the same as the name above
  version = '0.1',
  description = 'Python based hadoop command-line interface',
  author = 'mehikmat',
  author_email = 'me.hemant.available@gmail.com',
  license = "MIT",
  platforms = ["any"],
  url = 'https://github.com/mehikmat/PyHadoop', # use the URL to the github repo
  download_url = 'https://github.com/mehikmat/PyHadoop/tarball/0.1', # I'll explain this in a second
  keywords = ['hadoop', 'python', 'command-line'], # arbitrary keywords
  long_description=open('README.md').read(),
  classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
  entry_points={
        "console_scripts": [
            "pyhadoop=pyhadoop:main",
            "pyhadoop%s=pyhadoop:main" % sys.version[:1],
            "pyhadoop%s=pyhadoop:main" % sys.version[:3],
        ],
    },
)


import sys

if __package__ == '':
    import os
    print ("inside main__pack")  
    path = os.path.dirname(os.path.dirname(__file__))
    sys.path.insert(0, path)

import hadoopy

if __name__ == '__main__':    
    sys.exit(hadoopy.main())


import argparse
import sys
import os
from resources import command_map

__author__ = 'hikmat'

"""
Module docstring.
This serves as a long usage message.
"""

HADOOP_HOME = ""

def set_vars():
    global HADOOP_HOME
    HADOOP_HOME = os.getenv("HADOOP_HOME","NULL")   

def validate_vars():
	if HADOOP_HOME == "NULL":
		print("HADOOP_HOME has not been set. Please set it.")
		exit()	

def main():    
    set_vars()
    validate_vars()

    parser = argparse.ArgumentParser(description='Processes commands aganist hadoop')
    parser.add_argument("command", help='hadoop command to be executed')	
    args = parser.parse_args()
    cmd = args.command    
    cmd_exec=''

    if cmd in command_map.keys():
       cmd_exec = command_map[cmd]
    else:
       print("Oops!!! Unknown command!!!")      
       print("Valid commands are:")
       print("========================")
       print("$> pyhadoop start")
       print("$> pyhadoop stop")
       print("$> pyhadoop cp src dest")
       print("$> pyhadoop mv src dest")
       print("========================\n")
       sys.exit(1)

    cmd_exec = cmd_exec.replace("$HADOOP_HOME",HADOOP_HOME)
    
    print("Executing {} .........".format(cmd_exec))

    os.system(cmd_exec)
    	

if __name__ == '__main__':   
    sys.exit(main())